@@ -16,8 +16,3 @@ class InvalidAuthorizationCredentials(AuthenticationFailed):
     msg = _('Invalid Authorization header.')
     default_code = 'invalid_authorization_credentials'
 
-
-class InvalidAuthorizationHeaderPrefix(AuthenticationFailed):
-    status_code = 401
-    msg = _('Authentication credentials were not provided.')
-    default_code = 'invalid_authorization_header_prefix'
