@@ -1,3 +1,5 @@
+import jwt
+
 from rest_framework.permissions import BasePermission
 
 from rest_framework_jwt.authentication import JSONWebTokenAuthentication
@@ -9,6 +11,12 @@ class IsNotBlacklisted(BasePermission):
     message = _('You have been blacklisted.')
 
     def has_permission(self, request, view):
-        return not BlacklistedToken.objects.filter(
-            token=JSONWebTokenAuthentication.get_token_from_request(request)
-        ).exists()
+        token = JSONWebTokenAuthentication.get_token_from_request(request)
+
+        # Don't check the blacklist for requests with no token.
+        if token is None:
+            return True
+
+        # The token should already be validated before we call this.
+        payload = jwt.decode(token, None, False)
+        return not BlacklistedToken.is_blocked(token, payload)
