@@ -10,7 +10,6 @@ import uuid
 
 from django.apps import apps
 from django.contrib.auth import get_user_model
-from django.utils.encoding import force_str
 
 from rest_framework import serializers
 from rest_framework.utils.encoders import JSONEncoder
@@ -204,12 +203,6 @@ def jwt_create_response_payload(
 def check_payload(token):
     from rest_framework_jwt.authentication import JSONWebTokenAuthentication
 
-    if apps.is_installed('rest_framework_jwt.blacklist'):
-        from rest_framework_jwt.blacklist.models import BlacklistedToken
-        if BlacklistedToken.objects.filter(token=force_str(token)).exists():
-            msg = _('Token is blacklisted.')
-            raise serializers.ValidationError(msg)
-
     try:
         payload = JSONWebTokenAuthentication.jwt_decode_token(token)
     except jwt.ExpiredSignature:
@@ -222,6 +215,12 @@ def check_payload(token):
         msg = _('Invalid token.')
         raise serializers.ValidationError(msg)
 
+    if apps.is_installed('rest_framework_jwt.blacklist'):
+        from rest_framework_jwt.blacklist.models import BlacklistedToken
+        if BlacklistedToken.is_blocked(token, payload):
+            msg = _('Token is blacklisted.')
+            raise serializers.ValidationError(msg)
+
     return payload
 
 
