@@ -41,6 +41,21 @@ def test_token_without_username_returns_validation_error(
     assert verify_response.json() == expected_output
 
 
+def test_token_without_required_token_id_returns_validation_error(
+    monkeypatch, user, call_auth_verify_endpoint
+):
+    monkeypatch.setattr(api_settings, "JWT_TOKEN_ID", "require")
+    payload = JSONWebTokenAuthentication.jwt_create_payload(user)
+    payload.pop("jti")
+    auth_token = JSONWebTokenAuthentication.jwt_encode_payload(payload)
+
+    expected_output = {"non_field_errors": [_("Invalid token.")]}
+
+    verify_response = call_auth_verify_endpoint(auth_token)
+
+    assert verify_response.json() == expected_output
+
+
 def test_token_with_invalid_username_returns_validation_error(
     user, call_auth_verify_endpoint
 ):
